Package: MCbiclust
Type: Package
Title: Massive correlating biclusters for gene expression data and
        associated methods
Version: 1.35.0
Date: 2024-02-02
Author: Robert Bentham
Maintainer: Robert Bentham <robert.bentham.11@ucl.ac.uk>
Description: Custom made algorithm and associated methods for finding,
        visualising and analysing biclusters in large gene expression
        data sets. Algorithm is based on with a supplied gene set of
        size n, finding the maximum strength correlation matrix
        containing m samples from the data set.
Depends: R (>= 3.4)
Imports: BiocParallel, graphics, utils, stats, AnnotationDbi, GO.db,
        org.Hs.eg.db, GGally, ggplot2, scales, cluster, WGCNA
Suggests: gplots, knitr, rmarkdown, BiocStyle, gProfileR, MASS, dplyr,
        pander, devtools, testthat, GSVA
License: GPL-2
biocViews: ImmunoOncology, Clustering, Microarray, StatisticalMethod,
        Software, RNASeq, GeneExpression
RoxygenNote: 6.0.1
VignetteBuilder: knitr
LazyData: true
git_url: https://git.bioconductor.org/packages/MCbiclust
git_branch: devel
git_last_commit: 538a41b
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
NeedsCompilation: no
Packaged: 2025-10-31 22:39:23 UTC; biocbuild
