# MCbiclust

MCbiclust is a R package for running massively correlating biclustering analysis. MCbiclust aims to find large scale biclusters with selected features being highly correlated with each other over a subset of samples.

The package was originally designed as part of my PhD at UCL, in order to solve a problem in bioinformatics: to find biclusters representing different modes of regulation of mitochondria gene expression in disease states such as breast cancer.
The same methods however, can be used on any gene expression data set to find biclusters of interest.

