% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{Mitochondrial_genes}
\alias{Mitochondrial_genes}
\title{List of known mitochondrial genes}
\format{A Character vector of the HGNC approved gene names}
\source{
\url{https://www.broadinstitute.org/publications/broad807s}
}
\usage{
Mitochondrial_genes
}
\value{
NA
}
\description{
A dataset from MitoCarta1.0 containing the 1023 mitochondrial genes
Availiable from the broad institute: http://www.broadinstitute.org/scientific-community/science/programs/metabolic-disease-program/publications/mitocarta/mitocarta-in-0
}
\keyword{datasets}
